@@ -38,6 +38,7 @@ EXTENSIONS = {
     'cu': {'text', 'cuda'},
     'cuh': {'text', 'cuda'},
     'cxx': {'text', 'c++'},
+    'cylc': {'text', 'cylc'},
     'dart': {'text', 'dart'},
     'def': {'text', 'def'},
     'dll': {'binary'},
@@ -51,6 +52,10 @@ EXTENSIONS = {
     'erb': {'text', 'erb'},
     'exe': {'binary'},
     'eyaml': {'text', 'yaml'},
+    'f03': {'text', 'fortran'},
+    'f08': {'text', 'fortran'},
+    'f90': {'text', 'fortran'},
+    'f95': {'text', 'fortran'},
     'feature': {'text', 'gherkin'},
     'fish': {'text', 'fish'},
     'fits': {'binary', 'fits'},
@@ -96,6 +101,7 @@ EXTENSIONS = {
     'jenkinsfile': {'text', 'groovy', 'jenkins'},
     'jinja': {'text', 'jinja'},
     'jinja2': {'text', 'jinja'},
+    'jl': {'text', 'julia'},
     'jpeg': {'binary', 'image', 'jpeg'},
     'jpg': {'binary', 'image', 'jpeg'},
     'js': {'text', 'javascript'},
@@ -280,6 +286,7 @@ NAMES = {
     '.gitlint': EXTENSIONS['ini'] | {'gitlint'},
     '.gitmodules': {'text', 'gitmodules'},
     '.hgrc': EXTENSIONS['ini'] | {'hgrc'},
+    '.isort.cfg': EXTENSIONS['ini'] | {'isort'},
     '.jshintrc': EXTENSIONS['json'] | {'jshintrc'},
     '.mailmap': {'text', 'mailmap'},
     '.mention-bot': EXTENSIONS['json'] | {'mention-bot'},
